@@ -14,7 +14,7 @@ $admin_pass = 'adminpassword';     # !!!EDIT!!!
  $tab = << "TERMI";
  $sql_sessions_table (
         ID LONG,
-        S_ID VARCHAR(45),
+        S_ID VARCHAR(255),
         IP VARCHAR(20),
         EXPIRE INT,
         FLAG CHAR(1),
@@ -25,11 +25,16 @@ TERMI
 $tab = << "TERMI";
  $sql_user_table (
         ID LONG,
-        USER VARCHAR(30),
-        PASSWORD VARCHAR(30),
-        DATA VARCHAR(1048576)
+        USER VARCHAR(50),
+        PASSWORD VARCHAR(50),
+        ACTIVE CHAR(1),
+        DATA VARCHAR(1048576),
+        CREATED DATETIME,
+        FNAME VARCHAR(50),
+        LNAME VARCHAR(50),
+        EMAIL VARCHAR(120)
         )
 TERMI
  sql_create_db($tab,$dbh);
-
-sql_query("insert into $sql_user_table values(MAXVAL('ID|$sql_user_table'),'$admin_user','$admin_pass','');",$dbh);
\ No newline at end of file
+ my $tm = time();
+ sql_query("insert into $sql_user_table values(MAXVAL('ID|$sql_user_table'),'$admin_user','$admin_pass','Y','',$tm,'Admin','','');",$dbh);
\ No newline at end of file
